Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(452)

Unified Diff: firmware/lib/include/vboot_common.h

Issue 3126013: Fix KeyBlockVerify() to take an explicit param for whether to use hash only. (Closed) Base URL: ssh://gitrw.chromium.org/vboot_reference.git
Patch Set: Fix one last typo Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | firmware/lib/vboot_common.c » ('j') | firmware/lib/vboot_common.c » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: firmware/lib/include/vboot_common.h
diff --git a/firmware/lib/include/vboot_common.h b/firmware/lib/include/vboot_common.h
index 74d85800b86084482db7e7f9f293f317bb8a078c..9885d50a35c3201991448f04a5e901ac950477ff 100644
--- a/firmware/lib/include/vboot_common.h
+++ b/firmware/lib/include/vboot_common.h
@@ -84,11 +84,11 @@ int VerifyDigest(const uint8_t* digest, const VbSignature *sig,
/* Checks the sanity of a key block of size [size] bytes, using public
* key [key]. If [key]==NULL, uses only the block checksum to verify
gauravsh 2010/08/17 22:24:13 If hash_only is non-zero
Randall Spangler 2010/08/17 22:43:55 Done.
* the key block. Header fields are also checked for sanity. Does not
* verify key index or key block flags. */
int KeyBlockVerify(const VbKeyBlockHeader* block, uint64_t size,
- const VbPublicKey *key);
+ const VbPublicKey *key, int hash_only);
/* Checks the sanity of a firmware preamble of size [size] bytes,
« no previous file with comments | « no previous file | firmware/lib/vboot_common.c » ('j') | firmware/lib/vboot_common.c » ('J')
@@ -84,11 +84,11 @@ int VerifyDigest(const uint8_t* digest, const VbSignature *sig,
/* Checks the sanity of a key block of size [size] bytes, using public
- * key [key]. If [key]==NULL, uses only the block checksum to verify
+ * key [key]. If hash_only, uses only the block checksum to verify
gauravsh 2010/08/17 22:24:13 If hash_only is non-zero
Randall Spangler 2010/08/17 22:43:55 Done.

Powered by Google App Engine
This is Rietveld 408576698